@@ -1,6 +1,6 @@
 package Statocles;
 # ABSTRACT: A static site generator
-$Statocles::VERSION = '0.052';
+$Statocles::VERSION = '0.053';
 # The currently-running site.
 # I hate this, but I know of no better way to ensure that we always have access
 # to a Mojo::Log object, while still being relatively useful, without having to
@@ -28,7 +28,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -126,12 +126,16 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords tadegenban Vladimir Lettiev
+=for stopwords Joel Berger tadegenban Vladimir Lettiev
 
 =over 4
 
 =item *
 
+Joel Berger <joel.a.berger@gmail.com>
+
+=item *
+
 tadegenban <tadegenban@gmail.com>
 
 =item *
