@@ -1,6 +1,6 @@
 package Statocles::App;
 # ABSTRACT: Base role for Statocles applications
-$Statocles::App::VERSION = '0.052';
+$Statocles::App::VERSION = '0.053';
 use Statocles::Base 'Role';
 use Statocles::Link;
 requires 'pages';
@@ -84,7 +84,7 @@ Statocles::App - Base role for Statocles applications
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -129,19 +129,26 @@ root. Use this to ensure two apps do not try to write the same path.
 
 =head1 METHODS
 
-=head2 pages()
+=head2 pages
+
+    my @pages = $app->pages;
 
 Get the pages for this app. Must return a list of L<Statocles::Page> objects.
 
-=head2 url( $url )
+=head2 url
 
-Get a URL to a page in this application. Prepends the L</url_root> if necessary. Strips
-"index.html" if possible.
+    my $app_url = $app->url( $path );
 
-=head2 link( %args )
+Get a URL to a page in this application. Prepends the app's L<url_root
+attribute|/url_root> if necessary. Strips "index.html" if possible.
 
-Create a link to a page in this application. C<%args> are attributes to be given to
-L<Statocles::Link> constructor.
+=head2 link
+
+    my $link = $app->link( %args )
+
+Create a link to a page in this application. C<%args> are attributes to be
+given to L<Statocles::Link> constructor. The app's L<url_root
+attribute|/url_root> is prepended, if necessary.
 
 =head1 INCLUDED APPS
 
