@@ -1,6 +1,6 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.052';
+$Statocles::App::Blog::VERSION = '0.053';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store::File;
@@ -488,7 +488,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -560,37 +560,57 @@ So, given a document with tags "foo", and "bar":
 
 =head1 METHODS
 
-=head2 command( app_name, args )
+=head2 command
+
+    my $exitval = $app->command( $app_name, @args );
 
 Run a command on this app. The app name is used to build the help, so
 users get exactly what they need to run.
 
-=head2 make_slug( $title )
+=head2 make_slug
+
+    my $slug = $app->make_slug( $title );
 
 Given a post title, remove special characters to create a slug.
 
-=head2 post_pages()
+=head2 post_pages
 
-Get the individual post Statocles::Page objects.
+    my @pages = $app->post_pages;
 
-=head2 post_files()
+Get the individual post L<Statocles::Page> objects.
 
-Get all the post collateral files.
+=head2 post_files
 
-=head2 index()
+    my @pages = $app->post_files;
 
-Get the index page (a L<list page|Statocles::Page::List>) for this application.
-This includes all the relevant feed pages.
+Get all the post collateral files as L<Statocles::Page> objects. Markdown
+files will be created as L<Statocles::Page::Document> objects, any other files
+will be L<Statocles::Page::File> objects.
 
-=head2 tag_pages()
+=head2 index
 
-Get L<pages|Statocles::Page> for the tags in the blog post documents.
+    my @pages = $app->index( @post_pages );
 
-=head2 pages()
+Build the index page (a L<list page|Statocles::Page::List>) and all related feed pages
+out of the given post pages (built from L<the post_pages method|/post_pages>).
+
+=head2 tag_pages
+
+    my @pages = $app->tag_pages( @post_pages );
+
+Get L<pages|Statocles::Page> for the tags in the given blog post documents
+(build from L<the post_pages method|/post_pages>, including relevant feed
+pages.
+
+=head2 pages
+
+    my @pages = $app->pages;
 
 Get all the L<pages|Statocles::Page> for this application.
 
-=head2 tags()
+=head2 tags
+
+    my @links = $app->tags;
 
 Get a set of L<link objects|Statocles::Link> suitable for creating a list of
 tag links. The common attributes are:
@@ -598,7 +618,9 @@ tag links. The common attributes are:
     text => 'The tag text'
     href => 'The URL to the tag page'
 
-=head2 recent_posts( $count, %filter )
+=head2 recent_posts
+
+    my @pages = $app->recent_posts( $count, %filter );
 
 Get the last $count recent posts for this blog. Useful for templates and site
 index pages.
@@ -606,11 +628,20 @@ index pages.
 %filter is an optional set of filters to apply to only show recent posts
 matching the given criteria. The following filters are available:
 
-    tags        -> (string) Only show posts with the given tag
+=over 4
 
-=head2 page_url( page )
+=item tags
 
-Return the absolute URL to this page, removing the "/index.html" if necessary.
+(string) Only show posts with the given tag
+
+=back
+
+=head2 page_url
+
+    my $url = $app->page_url( $page )
+
+Return the absolute URL to this L<page object|Statocles::Page>, removing the
+"/index.html" if necessary.
 
 =head1 COMMANDS
 
