@@ -1,6 +1,6 @@
 package Statocles::App::Perldoc;
 # ABSTRACT: Render documentation for Perl modules
-$Statocles::App::Perldoc::VERSION = '0.052';
+$Statocles::App::Perldoc::VERSION = '0.053';
 use Statocles::Base 'Class';
 use Statocles::Page::Plain;
 use Scalar::Util qw( blessed );
@@ -181,7 +181,7 @@ sub _module_href {
     return $page_url;
 }
 
-
+# Run Pod::Weaver on the POD in the given path
 sub _weave_module {
     my ( $self, $path ) = @_;
 
@@ -272,7 +272,7 @@ Statocles::App::Perldoc - Render documentation for Perl modules
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -305,11 +305,9 @@ The path to the Pod::Weaver configuration file
 
 =head2 pages
 
-Render the requested modules as HTML.
+    my @pages = $app->pages;
 
-=head2 _weave_module( $path )
-
-Run Pod::Weaver on the POD in the given path
+Render the requested modules as HTML. Returns an array of L<Statocles::Page> objects.
 
 =head1 AUTHOR
 
