@@ -1,6 +1,6 @@
 package Statocles::App::Static;
 # ABSTRACT: Manage static files like CSS, JS, images, and other untemplated content
-$Statocles::App::Static::VERSION = '0.052';
+$Statocles::App::Static::VERSION = '0.053';
 use Statocles::Base 'Class';
 use Statocles::Page::File;
 with 'Statocles::App';
@@ -49,7 +49,7 @@ Statocles::App::Static - Manage static files like CSS, JS, images, and other unt
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -66,7 +66,9 @@ The L<store|Statocles::Store> containing this app's files. Required.
 
 =head2 pages
 
-Get the L<pages|Statocles::Page> for this app.
+    my @pages = $app->pages;
+
+Get the L<page objects|Statocles::Page> for this app.
 
 =head1 AUTHOR
 
