@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.052';
+$Statocles::Command::VERSION = '0.053';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -35,7 +35,7 @@ sub main {
     );
     return pod2usage(0) if $opt{help};
 
-    if ( $opt{version} ) {
+    if ( $opt{version} || ( $opt{verbose} && !@argv ) ) {
         say "Statocles version $Statocles::Command::VERSION (Perl $^V)";
         return 0;
     }
@@ -470,7 +470,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -489,7 +489,9 @@ The L<site|Statocles::Site> we're working with.
 
 =head1 METHODS
 
-=head2 main( @argv )
+=head2 main
+
+    my $exitval = $cmd->main( @argv );
 
 Run the command given in @argv. See L<statocles> for a list of commands and
 options.
