@@ -1,6 +1,6 @@
 package Statocles::Deploy;
 # ABSTRACT: Base role for ways to deploy a site
-$Statocles::Deploy::VERSION = '0.052';
+$Statocles::Deploy::VERSION = '0.053';
 use Statocles::Base 'Role';
 
 
@@ -24,7 +24,7 @@ Statocles::Deploy - Base role for ways to deploy a site
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -43,7 +43,9 @@ URLs.
 
 =head1 METHODS
 
-=head2 deploy( FROM_STORE, MESSAGE )
+=head2 deploy
+
+    my @paths = $deploy->deploy( $from_store, $message );
 
 Deploy the site, copying from the given L<store object|Statocles::Store>, optionally
 committing with the given message. Returns a list of file paths deployed.
