@@ -1,6 +1,6 @@
 package Statocles::Deploy::File;
 # ABSTRACT: Deploy a site to a folder on the filesystem
-$Statocles::Deploy::File::VERSION = '0.052';
+$Statocles::Deploy::File::VERSION = '0.053';
 use Statocles::Base 'Class';
 with 'Statocles::Deploy';
 
@@ -49,7 +49,7 @@ Statocles::Deploy::File - Deploy a site to a folder on the filesystem
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -65,9 +65,12 @@ The path to deploy to.
 
 =head1 METHODS
 
-=head2 deploy( FROM_STORE, MESSAGE )
+=head2 deploy
 
-Deploy the site, copying from the given store.
+    my @paths = $deploy->deploy( $from_store, $message );
+
+Deploy the site, copying from the given L<from_store|Statocles::Store> with the
+given commit message (if applicable). Returns the paths that were deployed.
 
 =head1 SEE ALSO
 
