@@ -1,6 +1,6 @@
 package Statocles::Deploy::Git;
 # ABSTRACT: Deploy a site to a Git repository
-$Statocles::Deploy::Git::VERSION = '0.052';
+$Statocles::Deploy::Git::VERSION = '0.053';
 use Statocles::Base 'Class';
 extends 'Statocles::Deploy::File';
 
@@ -140,7 +140,7 @@ Statocles::Deploy::Git - Deploy a site to a Git repository
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -166,9 +166,12 @@ The name of the remote to deploy to. Defaults to 'origin'.
 
 =head1 METHODS
 
-=head2 deploy( FROM_STORE, MESSAGE )
+=head2 deploy
 
-Deploy the site, copying from the given store. Returns the files deployed.
+    my @paths = $deploy->deploy( $from_store, $message );
+
+Deploy the site, copying from the given L<from_store|Statocles::Store> with the
+given commit message (if applicable). Returns the paths that were deployed.
 
 =head1 SEE ALSO
 
