@@ -1,6 +1,6 @@
 package Statocles::Link;
 # ABSTRACT: A link object to build <a> and <link> tags
-$Statocles::Link::VERSION = '0.052';
+$Statocles::Link::VERSION = '0.053';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 
@@ -77,7 +77,7 @@ Statocles::Link - A link object to build <a> and <link> tags
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -117,7 +117,9 @@ tags.
 
 =head1 METHODS
 
-=head2 new_from_element( $element )
+=head2 new_from_element
+
+    my $link = Statocles::Link->new_from_element( $dom_elem );
 
 Construct a new Statocles::Link out of a Mojo::DOM element (either an <a> or a <link>).
 
