@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::VERSION = '0.052';
+$Statocles::Page::VERSION = '0.053';
 use Statocles::Base 'Role';
 use Statocles::Template;
 
@@ -133,6 +133,7 @@ sub render {
     );
 
     my $content = $self->template->render(
+        # XXX: This is suboptimal. Isn't vars() enough?
         ( $self->can( 'content' ) ? ( content => $self->content( %vars ) ) : () ),
         %vars,
     );
@@ -174,7 +175,7 @@ Statocles::Page - Render documents into HTML
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -278,24 +279,36 @@ protocol|http://sitemaps.org> for details.
 
 =head2 vars
 
+    my %vars = $page->vars;
+
 Get extra template variables for this page
 
 =head2 render
 
-Render the page, using the L<template|Statocles::Page/template> and wrapping
-with the L<layout|Statocles::Page/layout>.
+    my $html = $page->render( %vars );
 
-=head2 links( KEY )
+Render the page, using the L<template|Statocles::Page/template> and wrapping
+with the L<layout|Statocles::Page/layout>. Give any extra C<%vars> to the
+template, layout, and page C<content> method (if applicable).
+
+=head2 links
+
+    my @links = $page->links( $key );
+    my $link = $page->links( $key );
 
 Get the links set for the given key. See L<the links attribute|/links> for some
 commonly-used keys. Returns a list of L<link objects|Statocles::Link>. In
 scalar context, returns the first link in the list.
 
-=head2 basename()
+=head2 basename
+
+    my $name = $page->basename;
 
 Get the base file name of this page. Everything after the last C</>.
 
-=head2 dirname()
+=head2 dirname
+
+    my $dir = $page->dirname;
 
 Get the full directory to this page. Anything that isn't part of L</basename>.
 
