@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.052';
+$Statocles::Page::Document::VERSION = '0.053';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
@@ -119,7 +119,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -153,33 +153,45 @@ most important attributes are:
 
 =head1 METHODS
 
-=head2 content( vars )
+=head2 content
+
+    my $html = $page->content( %vars );
 
 Generate the document HTML by processing template directives and converting
 Markdown. C<vars> is a set of name-value pairs to give to the template.
 
 =head2 vars
 
+    my %vars = $page->vars;
+
 Get the template variables for this page.
 
 =head2 sections
 
-Get a list of content divided into sections. The Markdown "---" marker divides
-sections.
+    my @sections = $page->sections;
 
-=head2 tags()
+Get a list of rendered HTML content divided into sections. The Markdown "---"
+marker divides sections.
+
+=head2 tags
+
+    my @tags = $page->tags;
 
 Get the list of tags for this page.
 
-=head2 template()
+=head2 template
 
-The L<template|Statocles::Template> for this page. If the document has a template,
+    my $tmpl = $page->template;
+
+The L<template object|Statocles::Template> for this page. If the document has a template,
 it will be used. Otherwise, the L<template attribute|Statocles::Page/template> will
 be used.
 
-=head2 layout()
+=head2 layout
 
-The L<layout template|Statocles::Template> for this page. If the document has a layout,
+    my $tmpl = $page->layout;
+
+The L<layout template object|Statocles::Template> for this page. If the document has a layout,
 it will be used. Otherwise, the L<layout attribute|Statocles::Page/layout> will
 be used.
 
