@@ -1,6 +1,6 @@
 package Statocles::Page::File;
 # ABSTRACT: A page wrapping a file (handle)
-$Statocles::Page::File::VERSION = '0.052';
+$Statocles::Page::File::VERSION = '0.053';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 
@@ -40,7 +40,7 @@ Statocles::Page::File - A page wrapping a file (handle)
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -80,7 +80,9 @@ Dies. This page has no templates and no template variables.
 
 =head2 render
 
-Return
+    my $fh = $page->render;
+
+Return the filehandle to the file containing the content for this page.
 
 =head1 AUTHOR
 
