@@ -1,6 +1,6 @@
 package Statocles::Page::List;
 # ABSTRACT: A page presenting a list of other pages
-$Statocles::Page::List::VERSION = '0.052';
+$Statocles::Page::List::VERSION = '0.053';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use List::Util qw( max );
@@ -118,7 +118,7 @@ Statocles::Page::List - A page presenting a list of other pages
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -162,7 +162,9 @@ content may appear 3-4 items down the page.
 
 =head2 paginate
 
-Build a paginated list of Statocles::Page::List objects.
+    my @pages = Statocles::Page::List->paginate( %args );
+
+Build a paginated list of L<Statocles::Page::List> objects.
 
 Takes a list of key-value pairs with the following keys:
 
@@ -177,6 +179,8 @@ page first (if any).
 
 =head2 vars
 
+    my %vars = $page->vars;
+
 Get the template variables for this page.
 
 =head1 AUTHOR
