@@ -1,6 +1,6 @@
 package Statocles::Page::ListItem;
 # ABSTRACT: An item in a List page
-$Statocles::Page::ListItem::VERSION = '0.052';
+$Statocles::Page::ListItem::VERSION = '0.053';
 use Statocles::Base 'Class';
 use Mojo::DOM;
 
@@ -53,13 +53,13 @@ sub _rewrite_content {
             my $url = $el->attr( $attr );
 
             # relative URLs must be absolute
-            if ( $url !~ m{^(?:[a-zA-Z]:)?//?} ) {
+            if ( $url !~ m{^(?:(?:[a-zA-Z]+:)|//?)} ) {
                 $url = $self->page->dirname . '/' . $url;
             }
 
             # absolute URLs may be full
             if ( $self->rewrite_mode eq 'full' ) {
-                if ( $url !~ m{^(?:[a-zA-Z]:)?//} ) {
+                if ( $url !~ m{^(?:(?:[a-zA-Z]+:)|//)} ) {
                     $url = $self->page->site->url( $url );
                 }
             }
@@ -95,7 +95,7 @@ Statocles::Page::ListItem - An item in a List page
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -120,7 +120,7 @@ rewriting the content.
 
 =head1 METHODS
 
-=head2 DOES( $class )
+=head2 DOES
 
 This page proxies everything necessary to be a page object, without consuming
 the L<page role|Statocles::Page>.
@@ -130,12 +130,16 @@ the L<page role|Statocles::Page>.
 Methods are proxyed to the L<page object|/page> so that this object appears
 mostly as the page inside of it.
 
-=head2 content()
+=head2 content
+
+    my $html = $page->content;
 
 Get the content for this page. Rewrite any links, images, or other according to the
 L<rewrite_mode attributes|/rewrite_mode>.
 
-=head2 sections()
+=head2 sections
+
+    my @sections = $page->sections;
 
 Get a list of content divided into sections. The Markdown "---" marker divides
 sections. Rewrite any links, images, or other according to the L<rewrite_mode
