@@ -1,6 +1,6 @@
 package Statocles::Plugin::LinkCheck;
 # ABSTRACT: Check links and images for validity during build
-$Statocles::Plugin::LinkCheck::VERSION = '0.052';
+$Statocles::Plugin::LinkCheck::VERSION = '0.053';
 use Statocles::Base 'Class';
 use Mojo::DOM;
 use Mojo::Util qw( url_escape url_unescape );
@@ -63,7 +63,7 @@ Statocles::Plugin::LinkCheck - Check links and images for validity during build
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -94,7 +94,9 @@ For example:
 
 =head1 METHODS
 
-=head2 check_pages( event )
+=head2 check_pages
+
+    $plugin->check_pages( $event );
 
 Check the pages inside the given
 L<Statocles::Event::Pages|Statocles::Event::Pages> event.
