@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.052';
+$Statocles::Site::VERSION = '0.053';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Text::Markdown;
@@ -44,7 +44,7 @@ has apps => (
 has index => (
     is => 'ro',
     isa => Str,
-    default => sub { '' },
+    default => sub { '/' },
 );
 
 
@@ -373,7 +373,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -417,8 +417,9 @@ that can be used later.
 
 =head2 index
 
-The page path to use for the site index. Make sure to include the leading
-slash (but C</index.html> is optional).
+The page path to use for the site index. Make sure to include the leading slash
+(but C</index.html> is optional). Defaults to C</>, so any app with C<url_root>
+of C</> will be the index.
 
 =head2 nav
 
@@ -478,13 +479,18 @@ Any object with a "markdown" method will work here.
 
 Register this site as the global site.
 
-=head2 app( name )
+=head2 app
+
+    my $app = $site->app( $name );
 
 Get the app with the given C<name>.
 
-=head2 nav( name )
+=head2 nav
 
-Get the list of links for the given nav. Each link is a L<Statocles::Link> object.
+    my @links = $site->nav( $key );
+
+Get the list of links for the given nav C<key>. Each link is a
+L<Statocles::Link> object.
 
     title - The title of the link
     href - The href of the link
@@ -493,13 +499,19 @@ If the named nav does not exist, returns an empty list.
 
 =head2 build
 
+    $site->build;
+
 Build the site in its build location.
 
 =head2 deploy
 
+    $site->deploy;
+
 Deploy the site to its destination.
 
-=head2 url( path )
+=head2 url
+
+    my $url = $site->url( $page_url );
 
 Get the full URL to the given path by prepending the C<base_url>.
 
