@@ -1,6 +1,6 @@
 package Statocles::Template;
 # ABSTRACT: A template object to pass around
-$Statocles::Template::VERSION = '0.052';
+$Statocles::Template::VERSION = '0.053';
 use Statocles::Base 'Class';
 use Mojo::Template;
 use Scalar::Util qw( blessed );
@@ -143,7 +143,7 @@ Statocles::Template - A template object to pass around
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -166,17 +166,27 @@ One or more stores to use for includes. Optional.
 
 =head1 METHODS
 
-=head2 BUILDARGS( )
+=head2 BUILDARGS
 
 Set the default path to something useful for in-memory templates.
 
-=head2 render( %args )
+=head2 render
+
+    my $html = $tmpl->render( %args )
 
 Render this template, passing in %args. Each key in %args will be available as
 a scalar in the template.
 
 =head2 coercion
 
+    my $coerce = Statocles::Template->coercion;
+
+    has template => (
+        is => 'ro',
+        isa => InstanceOf['Statocles::Template'],
+        coerce => Statocles::Template->coercion,
+    );
+
 A class method to returns a coercion sub to convert strings into template
 objects.
 
