@@ -1,6 +1,6 @@
 package Statocles::Test;
 # ABSTRACT: Common test routines for Statocles
-$Statocles::Test::VERSION = '0.052';
+$Statocles::Test::VERSION = '0.053';
 use Statocles::Base;
 use Test::More;
 use Test::Exception;
@@ -56,6 +56,12 @@ sub build_test_site_apps {
             page_size => 2,
         );
 
+        require Statocles::App::Plain;
+        my $plain = Statocles::App::Plain->new(
+            store => $share_dir->child( qw( app plain ) ),
+            url_root => '/',
+        );
+
         require Statocles::App::Static;
         my $static = Statocles::App::Static->new(
             store => $share_dir->child( qw( app static ) ),
@@ -65,6 +71,7 @@ sub build_test_site_apps {
         $site_args{apps} = {
             blog => $blog,
             static => $static,
+            plain => $plain,
         };
     }
 
@@ -298,7 +305,7 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -306,7 +313,9 @@ This module provides some common test routines for Statocles tests.
 
 =head1 SUBROUTINES
 
-=head2 build_test_site( %site_args )
+=head2 build_test_site
+
+    my $site = build_test_site( %site_args )
 
 Build a site for testing. The build and deploy will be set correctly to temporary
 directories. C<%site_args> will be given to the L<Statocles::Site|Statocles::Site>
@@ -314,14 +323,16 @@ constructor.
 
 You must provide a C<theme> (probably using the one in C<t/share/theme>).
 
-=head2 build_test_site_apps( $share_dir, %site_args )
+=head2 build_test_site_apps
+
+    my ( $site, $build_dir, $deploy_dir ) = build_test_site_apps( $share_dir, %site_args );
 
 Build a site for testing, with some apps. Returns the site, the build dir, and the
 deploy dir.
 
-    my ( $site, $build_dir, $deploy_dir ) = build_test_site_apps( $share_dir, %site_args );
+=head2 test_constructor
 
-=head2 test_constructor( class, args )
+    test_constructor( $class, %args )
 
 Test an object constructor. C<class> is the class to test. C<args> is a list of
 name/value pairs with the following keys:
@@ -340,7 +351,9 @@ are set to the correct defaults.
 
 =back
 
-=head2 test_pages( site, app, tests )
+=head2 test_pages
+
+    test_pages( $site, $app, %tests )
 
 Test the pages of the given app. C<tests> is a set of pairs of C<path> => C<callback>
 to test the pages returned by the app.
@@ -361,6 +374,8 @@ If the page is HTML, a L<Mojo::DOM> object ready for testing.
 
 =head2 build_temp_site
 
+    my ( $tmpdir, $config_fn, $config ) = build_temp_site( $share_dir );
+
 Build a config file so we can test config loading and still use
 temporary directories
 
