@@ -1,6 +1,6 @@
 package Statocles::Theme;
 # ABSTRACT: Templates, headers, footers, and navigation
-$Statocles::Theme::VERSION = '0.052';
+$Statocles::Theme::VERSION = '0.053';
 use Statocles::Base 'Class';
 use File::Share qw( dist_dir );
 use Scalar::Util qw( blessed );
@@ -97,7 +97,7 @@ Statocles::Theme - Templates, headers, footers, and navigation
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -144,16 +144,22 @@ The cached template objects for this theme.
 
 Handle the path :: share theme.
 
-=head2 read( $section => $name )
+=head2 read
+
+    my $tmpl = $theme->read( $section => $name )
 
 Read the template for the given C<section> and C<name> and create the
 L<template|Statocles::Template> object.
 
-=head2 build_template( $path, $content  )
+=head2 build_template
+
+    my $tmpl = $theme->build_template( $path, $content  )
 
 Build a new L<Statocles::Template> object with the given C<path> and C<content>.
 
-=head2 template( $section => $name )
+=head2 template
+
+    my $tmpl = $theme->template( $section => $name )
 
 Get the L<template|Statocles::Template> from the given C<section> with the
 given C<name>.
