@@ -1,6 +1,6 @@
 package Statocles::Util;
 # ABSTRACT: Various utility functions to reduce dependencies
-$Statocles::Util::VERSION = '0.052';
+$Statocles::Util::VERSION = '0.053';
 use Statocles::Base;
 use Exporter 'import';
 
@@ -38,7 +38,7 @@ Statocles::Util - Various utility functions to reduce dependencies
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,9 @@ This module contains some utility functions to help reduce non-core dependencies
 
 =head1 SUBROUTINES
 
-=head2 dircopy $source, $destination;
+=head2 dircopy
+
+    dircopy $source, $destination;
 
 Copy everything in $source to $destination, recursively.
 
